translate.storage.omegat.OmegaTFile

Package translate :: Package storage :: Module omegat :: Class OmegaTFile |
[hide private]
[frames] | no frames]

# Class OmegaTFile

source code

An OmegaT glossary file

Nested Classes | [hide private]
Inherited from `base.TranslationStore`: `UnitClass`

Instance Methods | [hide private]
__init__(self, inputfile=None, unitclass=OmegaTUnit) Construct an OmegaT glossary, optionally reading in from inputfile. | source code
_get_encoding(self) | source code
parse(self, input) parsese the given file or file source string | source code
__str__(self) Converts to a string representation that can be parsed back using parsestring(). | source code
Inherited from `base.TranslationStore`: `__getstate__`, `__setstate__`, `add_unit_to_index`, `addsourceunit`, `addunit`, `detect_encoding`, `findid`, `findunit`, `findunits`, `getids`, `getprojectstyle`, `getsourcelanguage`, `gettargetlanguage`, `getunits`, `isempty`, `makeindex`, `remove_unit_from_index`, `require_index`, `save`, `savefile`, `setprojectstyle`, `setsourcelanguage`, `settargetlanguage`, `translate`, `unit_iter` Inherited from `base.TranslationStore` (private): `_assignname` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
Inherited from `base.TranslationStore`: `parsefile`, `parsestring`

Class Variables | [hide private]
| Name = `_("OmegaT Glossary")` The human usable name of this store type
| Mimetypes = `["application/x-omegat-glossary"]` A list of MIME types associated with this store type
| Extensions = `["utf8"]` A list of file extentions associated with this store type
Inherited from `base.TranslationStore`: `sourcelanguage`, `suggestions_in_format`, `targetlanguage` Inherited from `base.TranslationStore` (private): `_binary`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, inputfile=None, unitclass=OmegaTUnit) (Constructor) | source code
Construct an OmegaT glossary, optionally reading in from inputfile. Overrides: object.__init__

### parse(self, input) | source code
parsese the given file or file source string Overrides: base.TranslationStore.parse

### __str__(self) (Informal representation operator) | source code
Converts to a string representation that can be parsed back using parsestring(). Overrides: object.__str__ (inherited documentation)